# YAML Fu

YAML Fu is a YAML templating tool

![PyPI - License](https://img.shields.io/pypi/l/yamlfu)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/yamlfu)
![PyPI](https://img.shields.io/pypi/v/yamlfu)
![PyPI - Downloads](https://img.shields.io/pypi/dm/yamlfu)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/joaompinto/yamlfu/Test)

## About

This package provides a command line utility and a Python library that generate YAML content fom processing yamlfu documents.

## Requirements
Python 3.6+


## Install

```bash
pip install yamlfu
```

## How to use (command ine tool)
```bash
yamlfu input.yaml
```

You can view examples of the templating capabilities at:
https://joaompinto.github.io/yamlfu/


